@@ -1,22 +1,8 @@
-/***************************************************************************
- *   This file is part of KDevelop                                         *
- *   Copyright 2008 Niko Sams <niko.sams@gmail.com>                        *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU Library General Public License as       *
- *   published by the Free Software Foundation; either version 2 of the    *
- *   License, or (at your option) any later version.                       *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU Library General Public     *
- *   License along with this program; if not, write to the                 *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2008 Niko Sams <niko.sams@gmail.com>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #ifndef CONTEXTBUILDER_H
 #define CONTEXTBUILDER_H
@@ -69,7 +55,7 @@ protected:
     KDevelop::QualifiedIdentifier identifierForNode(IdentifierAst* id) override;
     KDevelop::QualifiedIdentifier identifierForNode(SemiReservedIdentifierAst* id);
     KDevelop::QualifiedIdentifier identifierForNode(VariableIdentifierAst* id);
-    IdentifierPair identifierPairForNode(IdentifierAst* id);
+    IdentifierPair identifierPairForNode(IdentifierAst* id, bool isConstIdentifier = false);
     IdentifierPair identifierPairForNode(SemiReservedIdentifierAst* id);
     IdentifierPair identifierPairForNode(ReservedNonModifierIdentifierAst* id);
     QString stringForNode(IdentifierAst* node) const;
@@ -84,6 +70,8 @@ protected:
     void visitFunctionDeclarationStatement(FunctionDeclarationStatementAst* node) override;
     void visitClosure(ClosureAst* node) override;
     void visitUnaryExpression(UnaryExpressionAst* node) override;
+    void visitFunctionCallParameterListElement(FunctionCallParameterListElementAst* node) override;
+
     /**
      * don't overload in other builders, use @c openNamespace and @c closeNamespace instead.
      */
